@@ -2,9 +2,22 @@ import argparse
 from logging import INFO, basicConfig, getLogger
 from pathlib import Path
 
+from .. import DATASET_VERSION
 from ..download._helpers import download_openpack_from_zenodo
 
-LATEST_VERSION_ON_ZENODO = "v0.2.1"
+LATEST_VERSION_ON_ZENODO = DATASET_VERSION
+AVAILABLE_STREAMS_IN_ZENODO = [
+    "activity-1s",
+    "atr-qags",
+    "kinect-2d-kpt",
+    "system-order-sheet",
+    "system-ht-original",
+    "system-printer",
+    "e4-acc",
+    "e4-bvp",
+    "e4-eda",
+    "e4-temp",
+]
 
 basicConfig(level=INFO)
 logger = getLogger(__name__)
@@ -27,12 +40,13 @@ def make_parser():
     parser.add_argument(
         "-s",
         "--streams",
-        default="atr-qags,openpack-operations",
+        default="none",
         type=str,
         help=(
             "A list of data stream names that you want to download. "
             "Stream names must be separated by commas. "
-            "Defaul: atr-qags,openpack-operations"
+            "If none, all data in zenodo will be downloaded."
+            "Defaul: none"
         ))
 
     return parser
@@ -42,7 +56,10 @@ def entry_func():
     parser = make_parser()
     args = parser.parse_args()
 
-    streams = args.streams.split(",")
+    if args.streams == "none":
+        streams = AVAILABLE_STREAMS_IN_ZENODO
+    else:
+        streams = args.streams.split(",")
 
     logger.info("Donwload OpenPack dataset from zenodo.")
     logger.info(f" - dataset_dir : {args.dataset_dir}")
